@@ -24,7 +24,7 @@ fi
 config etc/rc.d/rc.php-fpm.new
 cp -a etc/httpd/php.ini-production etc/httpd/php.ini.new
 config etc/httpd/php.ini.new
-cp -a etc/php-fpm.conf.default etc/php-fpm.conf.new
-config etc/php-fpm.conf.new
+cp -a etc/php-fpm/php-fpm.conf.default etc/php-fpm/php-fpm.conf.new
+config etc/php-fpm/php-fpm.conf.new
 ( cd usr/bin ; rm -rf phar )
 ( cd usr/bin ; ln -sf /usr/bin/phar.phar phar )
